# UDS - UrbanDictionary CLI Searcher

[![Build Status](https://travis-ci.org/hvnsweeting/uds.svg?branch=master)](https://travis-ci.org/hvnsweeting/uds)

[![PyPI version](https://badge.fury.io/py/uds.svg)](https://badge.fury.io/py/uds)

## Version
Python3 only

## Install

```
pip install uds
```

## Example
[![asciicast](https://asciinema.org/a/TOCYosZbUXr1pk7NDTuPYtXbS.png)](https://asciinema.org/a/TOCYosZbUXr1pk7NDTuPYtXbS)

## Usage

```

$ uds ftw -n1  # -n limit number of meanings
UrbanDictionary results for 'ftw'
  1.     "For The Win."

   An enthusiastic emphasis to the end of a comment, message, or post. Sometimes genuine, but often sarcastic.

   Originated from the game show Hollywood Squares where the result of the player&aposs response is expected to win the game.

$ uds 31337
UrbanDictionary results for '31337'
  1.     Stands for Eleet. This is the original form of pointing out one&aposs greatness from any standpoint, beit athletic skills, academics, or even hacking or cracking processes.
   It was coined by a cdc group when they listened on a port :31337 and pointed out the Eleet-31337 - ness of their exploits.
  2.     to be elite. one who has skills.
  3.     31337 is the default port used by the Back Orifice trojan/Remote Admin Tool.
  4.     Hacker lingo for "elite." Numerical form of ELEET.
  5.     Spelling of "elite" primarily favoured by the alphabetically impaired.
  6.     The prime number between 31333 and 31357.
  7.     1. The most highly prized and regarded ICQ number

$ uds 520 -n1
UrbanDictionary results for '520'
  1.     Abbreviation for "I Love You" in net and SMS use in Chinese speaking world. It is an example of extensive use of numerical digits for their similar pronunciation of daily expressions in Chinese. In this case, 5 means "I", 2 means "love", 0 means "you".
```

## Authors
Viet Hung Nguyen <hvn@familug.org>
